# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals
from .clas import *
from .classroom import *
from .course import *
from .schedule import *
from .subject import *
from .user import *
from .news import *
from .notice import *
from .album import *
from .video import *
from .school import *
from .semester import *